# pavlok-oauth2
 
This file is the inital version of a oauth 2 client to interact with the Pavlok api. Install with pip and run. Then you can access the module by visiting http://localhost:8000/ . You can see the functioning docs, with endpoints, at http://localhost:8000/docs.

